pub struct PartialFileField<M> {
pub field_name: String,
pub source: MultipartFile<M>,
pub dest: Option<SavedFile>,
}Expand description
The file field that was being read when the save operation quit.
May be partially saved to the filesystem if dest is Some.
Fields
field_name: StringThe field name for the partial file.
source: MultipartFile<M>The partial file’s source in the multipart stream (may be partially read if dest
is Some).
dest: Option<SavedFile>The partial file’s entry on the filesystem, if the operation got that far.