MultipartFile

Struct MultipartFile 

pub struct MultipartFile<M> {
    pub filename: Option<String>,
    pub content_type: Mime,
    /* private fields */
}
A representation of a file in HTTP multipart/form-data.

Note that the file is not yet saved to the local filesystem; instead, this struct exposes Read and BufRead impls which point to the beginning of the file’s contents in the HTTP stream.

You can read it to EOF, or use one of the save() method to save it to disk.

Fields

filename: Option<String>

The filename of this entry, if supplied.

Warning: Client Provided / Untrustworthy

You should treat this value as untrustworthy because it is an arbitrary string provided by the client.

It is a serious security risk to create files or directories with paths based on user input. A malicious user could craft a path which can be used to overwrite important files, such as web templates, static assets, Javascript files, database files, configuration files, etc., if they are writable by the server process.

This can be mitigated somewhat by setting filesystem permissions as conservatively as possible and running the server under its own user with restricted permissions, but you should still not use user input directly as filesystem paths. If it is truly necessary, you should sanitize filenames such that they cannot be misinterpreted by the OS. Such functionality is outside the scope of this crate.

content_type: Mime

The MIME type (Content-Type value) of this file, if supplied by the client, or "applicaton/octet-stream" otherwise.

Note: Client Provided

Consider this value to be potentially untrustworthy, as it is provided by the client. It may be inaccurate or entirely wrong, depending on how the client determined it.

Some variants wrap arbitrary strings which could be abused by a malicious user if your application performs any non-idempotent operations based on their value, such as starting another program or querying/updating a database (web-search “SQL injection”).

Implementations

Source

impl<M> MultipartFile<M>

pub fn filename(&self) -> Option<&str>

👎Deprecated since 0.10.0: filename field is now public

Get the filename of this entry, if supplied.

Warning: Client Provided / Untrustworthy

You should treat this value as untrustworthy because it is an arbitrary string provided by the client.

It is a serious security risk to create files or directories with paths based on user input. A malicious user could craft a path which can be used to overwrite important files, such as web templates, static assets, Javascript files, database files, configuration files, etc., if they are writable by the server process.

This can be mitigated somewhat by setting filesystem permissions as conservatively as possible and running the server under its own user with restricted permissions, but you should still not use user input directly as filesystem paths. If it is truly necessary, you should sanitize filenames such that they cannot be misinterpreted by the OS. Such functionality is outside the scope of this crate.

pub fn content_type(&self) -> &Mime

👎Deprecated since 0.10.0: content_type field is now public

Get the MIME type (Content-Type value) of this file, if supplied by the client, or "applicaton/octet-stream" otherwise.

Note: Client Provided

Consider this value to be potentially untrustworthy, as it is provided by the client. It may be inaccurate or entirely wrong, depending on how the client determined it.

Some variants wrap arbitrary strings which could be abused by a malicious user if your application performs any non-idempotent operations based on their value, such as starting another program or querying/updating a database (web-search “SQL injection”).

Source

impl<M> MultipartFile<M>
where M: ReadEntry,

pub fn save(&mut self) -> SaveBuilder<&mut MultipartFile<M>>

Get a builder type which can save the file with or without a size limit.

pub fn save_to<W>(&mut self, out: W) -> Result<u64, Error>
where W: Write,

👎Deprecated since 0.10.0: use .save().write_to() instead

Save this file to the given output stream.

If successful, returns the number of bytes written.

Retries when io::Error::kind() == io::ErrorKind::Interrupted.

pub fn save_to_limited<W>(&mut self, out: W, limit: u64) -> Result<u64, Error>
where W: Write,

👎Deprecated since 0.10.0: use .save().size_limit(limit).write_to(out) instead

Save this file to the given output stream, truncated to limit (no more than limit bytes will be written out).

If successful, returns the number of bytes written.

Retries when io::Error::kind() == io::ErrorKind::Interrupted.

pub fn save_as<P>(&mut self, path: P) -> Result<SavedFile, Error>
where P: Into<PathBuf>,

👎Deprecated since 0.10.0: use .save().with_path(path) instead

Save this file to path.

Returns the saved file info on success, or any errors otherwise.

Retries when io::Error::kind() == io::ErrorKind::Interrupted.

pub fn save_in<P>(&mut self, dir: P) -> Result<SavedFile, Error>
where P: AsRef<Path>,

👎Deprecated since 0.10.0: use .save().with_dir(dir) instead

Save this file in the directory pointed at by dir, using a random alphanumeric string as the filename.

Any missing directories in the dir path will be created.

Returns the saved file’s info on success, or any errors otherwise.

Retries when io::Error::kind() == io::ErrorKind::Interrupted.

pub fn save_as_limited<P>( &mut self, path: P, limit: u64, ) -> Result<SavedFile, Error>
where P: Into<PathBuf>,

👎Deprecated since 0.10.0: use .save().size_limit(limit).with_path(path) instead

Save this file to path, truncated to limit (no more than limit bytes will be written out).

Any missing directories in the dir path will be created.

Returns the saved file’s info on success, or any errors otherwise.

Retries when io::Error::kind() == io::ErrorKind::Interrupted.

pub fn save_in_limited<P>( &mut self, dir: P, limit: u64, ) -> Result<SavedFile, Error>
where P: AsRef<Path>,

👎Deprecated since 0.10.0: use .save().size_limit(limit).with_dir(dir) instead

Save this file in the directory pointed at by dir, using a random alphanumeric string as the filename.

Truncates file to limit (no more than limit bytes will be written out).

Any missing directories in the dir path will be created.

Returns the saved file’s info on success, or any errors otherwise.

Retries when io::Error::kind() == io::ErrorKind::Interrupted.